@@ -290,8 +290,8 @@ def classify_page(page_id, class_id):
     update_object_by_key('page', 'id', page_id, {'tagged': True})
 
 def insert_manualStep(result, request_id):
-    query = f'INSERT INTO neuralplatform_manualstep(beingTagged, completed, result, request_id) ' + \
-            f'VALUES (0, 0, "{result}", {request_id});'
+    query = f'INSERT INTO neuralplatform_manualstep(status, result, request_id) ' + \
+            f'VALUES ("pending", "{result}", {request_id});'
     return run_insert(query)
 
 ######## DEPRECATED ########
